#include "colors.inc"	// Standard Color definitions
#include "textures.inc"	// Standard Texture definitions
#include "shapes.inc"
#include "glass.inc"

#declare epsilon = 0.0001

camera
{
  location  <17, 15, -15> // position of camera <X Y Z>
  look_at   <8.5, 1, 0> // point center of view at this point <X Y Z>
}

#macro ArrowConic(From, To, Radius)
#local Slope = 3
#local PointerBaseSize = 4
#local Dir = vnormalize(To-From)
union {
  cylinder {
    From,
    To+Dir*epsilon,
    Radius
  }
  cone {
    To,
    Radius*PointerBaseSize,
    To+Dir*Slope*PointerBaseSize*Radius,
    0
  }
}
#end

#macro ArrowCubic(From, To, Radius)
#local Slope = 1
#local PointerBaseSize = 1
#local Diff = To-From
#local Dir = vnormalize(Diff)
#local L = sqrt(Diff.x*Diff.x+Diff.y*Diff.y+Diff.z*Diff.z) 
union {
  prism {
    linear_spline
    0, L, 5,
    <Radius, Radius>,
    <Radius, -Radius>,
    <-Radius, -Radius>,
    <-Radius, Radius>,
    <Radius, Radius>
  }
  cone {
    To,
    Radius*PointerBaseSize,
    To+Dir*Slope*PointerBaseSize*Radius,
    0
  }
}
#end



// Background planes
#macro FirstQuadPlanes(MaxX, MaxY, MaxZ, SmallStep, BigStep)
intersection {
  // Begin insert your object
  intersection {
    union {
      plane {
        <0, 2, -1>,
        6/sqrt(5)
        texture {
          pigment {
            color <0.4, 0.9, 1>
          }
        }
      }
      plane {
        <0, 3, -1>,
         8/sqrt(10)
        texture {
          pigment {
            color <0.4, 0.9, 1>*0.9
          }
        }
      }
    }
    union {
      plane {
        <1, 5, -2>,
        15/sqrt(30)
        texture {
          pigment {
            color <1, 0.8, 0.4>*0.9
          }
        }
      }
      plane {
        <1, 6, -2>,
        16/sqrt(41)
        texture {
          pigment {
            color <1, 0.8, 0.4>*0.7
          }
        }
      }
      plane {
        <1, 6, -3>,
        18/sqrt(46)
        texture {
          pigment {
            color <1, 0.8, 0.4>
          }
        }
      }
      plane {
        <1, 7, -3>,
        20/sqrt(59)
        texture {
          pigment {
            color <1, 0.8, 0.4>*0.8
          }
        }
      }
    }
    texture {
      finish {
        ambient 0.3
      }
    }
  }
  // End insert your object
  box {
    <-epsilon, -epsilon, epsilon>,
    <MaxX, MaxY, -MaxZ>
  }
}

background {
  color <0,0,0>
}

intersection {
  box {
    <-epsilon, -epsilon, epsilon>,
    <MaxX, MaxY, -MaxZ>
  }
  union {
    plane {
    <1, 0, 0>,
    0
    hollow on
    }
    plane {
    <0, 1, 0>,
    0
    hollow on
    }
    plane {
    <0, 0, -1>,
    0
    hollow on
    }
    texture {
      checker
        texture {
          pigment {
            checker
              color <1, 1, 1>*0
              color <1, 1, 1>*0.6
          }
          scale SmallStep/BigStep
        }
        texture {
          pigment {
            checker
              color <1, 1, 1>*0.3
              color <1, 1, 1>*0.9
          }
          scale SmallStep/BigStep
        }
        scale BigStep
    }
  }
}

#local ArrowSize = SmallStep/20
#local AxInc = SmallStep/2
// X Axis
object {
//  ArrowConic(<0, -ArrowSize*0.6, ArrowSize*0.6>, <MaxX+AxInc, -ArrowSize*0.6, ArrowSize*0.6>, ArrowSize)
//  ArrowConic(<0, -ArrowSize, ArrowSize>, <MaxX+AxInc, -ArrowSize, ArrowSize>, ArrowSize)
  ArrowConic(<0, 0, 0>, <MaxX+AxInc, 0, 0>, ArrowSize)
  texture {
    pigment {
      color <1, 1, 1>*0.9
    }
    finish {
      ambient 0.3
    }
  }
}
  
// Y Axis
object {
//  ArrowConic(<-ArrowSize, 0, ArrowSize>, <-ArrowSize, MaxY+AxInc, ArrowSize>, ArrowSize)
  ArrowConic(<0, 0, 0>, <0, MaxY+AxInc, 0>, ArrowSize)
  texture {
    pigment {
      color <1, 1, 1>*0.9
    }
    finish {
      ambient 0.3
    }
  }
}
  
// Z Axis
object {
//  ArrowConic(<-ArrowSize, -ArrowSize, 0>, <-ArrowSize, -ArrowSize, -MaxZ-AxInc>, ArrowSize)
  ArrowConic(<0, 0, 0>, <0, 0, -MaxZ-AxInc>, ArrowSize)
  texture {
    pigment {
      color <1, 1, 1>*0.9
    }
    finish {
      ambient 0.3
    }
  }
}
  


#end

FirstQuadPlanes(21, 4, 9, 1, 5)

 


light_source {
  <50, 20, -40>
  color White
  shadowless
}

light_source {
  <20, 40, -50>
  color White
  shadowless
}

